from setuptools import setup, find_packages
from pathlib import Path

about = {}
with open(Path(__file__).parent / 'bro' / '__version__.py', 'r') as f:
    exec(f.read(), about)

license_content = (Path(__file__).parent / 'LICENSE.txt').read_text()
long_description = (Path(__file__).parent / 'README.md').read_text()
long_description = long_description.replace('X.Y.Z', about['__version__'])
long_description = long_description.replace('LICENSE-PLACEHOLDER', license_content)

setup(
    name='bro',
    version=about['__version__'],
    description='Open source python library for accessing BRO API',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/viktor-platform/bro',
    author='VIKTOR',
    author_email='support@viktor.ai',
    license='see LICENSE.txt',
    license_files=('LICENSE.txt',),
    packages=find_packages(exclude=['tests']),
    install_requires=[
        "xmltodict==0.13.0",
        "requests==2.28.2",
        "lxml==4.9.2",
        "pyproj==3.4.1"
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: Free To Use But Restricted',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    test_suite='tests',
    project_urls={
        'Example VIKTOR application': 'https://demo.viktor.ai/public/bro-app',
    #     'Source code example VIKTOR application': '',  # TODO: update
    }
)
